#!/usr/bin/env node
"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.ts
var import_commander = require("commander");

// src/lib.ts
var import_path = require("path");
var import_process = require("process");
var import_fs = require("fs");
var import_glob = require("glob");
var import_cross_fetch = __toESM(require("cross-fetch"));
var VERIFY_API_KEY_QUERY = `
  query ApiKeyToOrgID($api_key: String!) {
    api_key_to_org_id(api_key: $api_key)
  }
`;
var GET_SOURCE_MAP_URLS_QUERY = `
  query GetSourceMapUploadUrls($api_key: String!, $paths: [String!]!) {
    get_source_map_upload_urls(api_key: $api_key, paths: $paths)
  }
`;
var uploadSourcemaps = (_0) => __async(void 0, [_0], function* ({
  apiKey,
  appVersion,
  path,
  basePath
}) {
  if (!apiKey || apiKey === "") {
    if (process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY) {
      apiKey = process.env.HIGHLIGHT_SOURCEMAP_UPLOAD_API_KEY;
    } else {
      throw new Error("api key cannot be empty");
    }
  }
  const variables = {
    api_key: apiKey
  };
  const res = yield (0, import_cross_fetch.default)("https://pri.highlight.io", {
    method: "post",
    headers: {
      "Content-Type": "application/json",
      ApiKey: apiKey
    },
    body: JSON.stringify({
      query: VERIFY_API_KEY_QUERY,
      variables
    })
  }).then((response) => response.json()).then((data) => {
    return data;
  }).catch((e) => {
    console.log(e);
  });
  if (!res || !res.data || !res.data.api_key_to_org_id || res.data.api_key_to_org_id === "0") {
    throw new Error("invalid api key");
  }
  let organizationId = res.data.api_key_to_org_id;
  console.info(`Starting to upload source maps from ${path}`);
  const fileList = yield getAllSourceMapFiles([path]);
  if (fileList.length === 0) {
    console.error(
      `Error: No source maps found in ${path}, is this the correct path?`
    );
    console.info("Failed to upload source maps. Please see reason above.");
    return;
  }
  const s3Keys = fileList.map(
    ({ name }) => getS3Key(organizationId, appVersion, basePath, name)
  );
  const urlRes = yield (0, import_cross_fetch.default)("https://pri.highlight.io", {
    method: "post",
    headers: {
      "Content-Type": "application/json"
    },
    body: JSON.stringify({
      query: GET_SOURCE_MAP_URLS_QUERY,
      variables: {
        api_key: apiKey,
        paths: s3Keys
      }
    })
  }).then((response) => response.json()).then((data) => {
    return data;
  }).catch((e) => {
    console.log(e);
  });
  if (!urlRes || !urlRes.data || !urlRes.data.get_source_map_upload_urls || urlRes.data.get_source_map_upload_urls.length === 0) {
    console.error("Error: Unable to generate source map upload urls.", urlRes);
    console.info("Failed to upload source maps. Please see reason above.");
    return;
  }
  const uploadUrls = urlRes.data.get_source_map_upload_urls;
  yield Promise.all(
    fileList.map(({ path: path2 }, idx) => uploadFile(path2, uploadUrls[idx]))
  );
});
function getAllSourceMapFiles(paths) {
  return __async(this, null, function* () {
    const map = [];
    yield Promise.all(
      paths.map((path) => __async(this, null, function* () {
        const realPath = (0, import_path.join)((0, import_process.cwd)(), path);
        if ((0, import_fs.statSync)(realPath).isFile()) {
          map.push({
            path: realPath,
            name: (0, import_path.basename)(realPath)
          });
          return;
        }
        if (!(0, import_glob.globSync)("**/*.js.map", {
          cwd: realPath,
          nodir: true,
          ignore: "**/node_modules/**/*"
        }).length) {
          throw new Error(
            "No .js.map files found. Please double check that you have generated sourcemaps for your app."
          );
        }
        for (const file of (0, import_glob.globSync)("**/*.js?(.map)", {
          cwd: realPath,
          nodir: true,
          ignore: "**/node_modules/**/*"
        })) {
          map.push({
            path: (0, import_path.join)(realPath, file),
            name: file
          });
        }
      }))
    );
    return map;
  });
}
function getS3Key(organizationId, version, basePath, fileName) {
  if (version === null || version === void 0 || version === "" || !version) {
    version = "unversioned";
  }
  return `${organizationId}/${version}/${basePath}${fileName}`;
}
function uploadFile(filePath, uploadUrl) {
  return __async(this, null, function* () {
    const fileContent = (0, import_fs.readFileSync)(filePath);
    yield (0, import_cross_fetch.default)(uploadUrl, { method: "put", body: fileContent });
    console.log(`Uploaded ${filePath}`);
  });
}

// src/index.ts
import_commander.program.name("@highlight-run/sourcemap-uploader").description("Upload Javascript sourcemaps to Highlight");
import_commander.program.command("upload").requiredOption("-k, --apiKey <string>", "The Highlight api key").option("-av, --appVersion [string]", "The current version of your deploy").option(
  "-p, --path [string]",
  "Sets the directory of where the sourcemaps are",
  "."
).option(
  "-bp, --basePath [string]",
  "An optional base path for the uploaded sourcemaps",
  ""
).action(uploadSourcemaps);
import_commander.program.parse();
